# pyencoder
encode and decode python list to string array  

# usage
see example scripts.  
Currently, it supports encoding list of int, float, and str.  
implemented for sending data by string marker stream of Lab Streaming Layer
